# Installation

This section will guide you through the installation process of PyFlowery.

## pip

You can use pip to install PyFlowery.  
The command to use differs slightly depending on what operating system you use.

On Windows:

``` prolog title="Command Prompt"
py -m pip install pyflowery
```

On macOS and Linux:

``` prolog title="Bash"
python3 -m pip install pyflowery
```

## uv

You can also use [uv](https://astral.sh/uv) to store your dependencies.  
Use the following command to install PyFlowery:

``` prolog title="Command Prompt / Shell"
uv add pyflowery
```
